************************************
* Prepare Firm-Level Data		   *
* Andy Garin (agarin@illinois.edu) *
************************************

*
*Reads in merged firm-level data sets from old server
*
*Applies sample restrictions, merges in shocks, cleans analysis variables
*
*See readme for variable descriptions
*


cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"



*****************************
**1. Read in data 
*****************************

global Data  "${path}/Aggregate Shock/Data"
clear all
set more off

set matsize 11000


*Merged data from old server

use "${path}/Aggregate Shock/Data/mainsamp_notclean.dta", clear
cap drop *nshs6*
cap drop taxes



*****************************
**2. Preliminary Sample Selection
*****************************
*Make Panel
tsset nipc year

*Keep firms with exports in each year 2005, 2006, and 2007
keep if sample3 == 1

*Keep firms with QP employment in each year 2005, 2006, and 2007
egen emptemp=max(inrange(year,2005,2007)*(emp==0)), by(nipc)
drop if emptemp==1



*Drop firms from sample with extreme *pre-period* growth in employment, sales, or exports
*Calculate percent change and log change, remove firms above 99th percentile growth or below 1st percentile (decline) 

gen g1 = logturnover-L2.logturnover if year==2007
gen g2 = turnover_s3-L2.turnover_s3 if year==2007
gen g3 = logexports-L2.logexports if year==2007
gen g4 = exports_s3-L2.exports_s3 if year==2007
gen g5 = logemployees-L2.logemployees if year==2007
gen g6 = employees_s3-L2.employees_s3 if year==2007

egen pt1_pre = max(g1), by(nipc)
egen pt2_pre = max(g2), by(nipc)
egen pt3_pre = max(g3), by(nipc)
egen pt4_pre = max(g4), by(nipc)
egen pt5_pre = max(g5), by(nipc)
egen pt6_pre = max(g6), by(nipc)



forval i=1/6{
	summ pt`i'  if sample3==1 &year==2007, d
	local t1 = r(p1)
	local t2 = r(p99)
	
	replace sample3 = 0 if pt`i'<`t1'
	replace sample3 = 0 if pt`i'>`t2'
}
keep if sample3 == 1
drop pt?_pre



*Calculate average pre-period employment
egen preemployees = total( employees * inrange(year,2005,2007) ), by(nipc)
replace preemp = preemp/ 3

*MAIN SAMPLE DEFINITION
*  --Mid sized firms (3-100 employees in pre-period)
*  --Firms do not do more than 90% of exporting to only Angola or only Spain


gen mainsamp = 0
replace mainsamp = 1 if inrange(preemployees,3,100)
replace mainsamp = 0 if expshrESP>.9|expshrAGO>.9

*For robustness, apply size restriction but not Angola/Spain restriction
gen altASsamp = 0
replace altASsamp = 1 if inrange(preemployees,3,100)


*Make Panel
tsset nipc year



***********************************
**3. Add/winsorize main shock vars
***********************************

**Drop old versions of shock variable

cap drop *nshs6*
cap drop shock*

*Add main shock variables and decomposed elements

*Here, reference replication copy
merge m:1 nipcbdp using "${path}/Aggregate Shock/replication/data_out/shocks_hs6.dta", keep(1 3) nogen


unab tlist:  shock* comshock* idshock* 

*Winsorize shocks at 5th and 95th percentiles

local ny : word count `tlist'

forvalues y = 1/`ny' {
	
	local var : word `y' of `tlist' 
	local inter : word `y' of `intterm'	
	
	*save original
	gen raw`var' = `var'
	 
	*Check: drop if shock is zero (implies no exports)
	replace `var' = . if `var'==0
	
	summ `var'  if mainsamp==1 &year==2007, d
	local t1 = r(p5)
	local t2 = r(p95)
	local t75= r(p75)
	local t25 = r(p25)
	local tmed = r(p50)

	*winsorize
	replace `var' = `t1' if `var'<`t1' & `var'!=.
	replace `var' = `t2' if `var'>`t2' & `var'!=.

	
	*Store sample moments
	summ `var'  if sample3==1 &year==2007, d
	local xsd = r(sd)
	local xmn = r(mean)
	
	gen sd_`var' = round(`xsd',.001)
	gen mn_`var' = round( `xmn',.001)	
	
	
}


*Create leave-one-out "spillover" shocks: average shock of all other firms in industry and municipality

foreach sk in `tlist' {
	foreach ind in 4 5{		
	gen temp_`sk' = `sk'*(mainsamp==1)
	egen temp_tot = total(temp_`sk'), by(nace`ind' municipality year)
	egen temp_num = total(temp_`sk'!=0), by(nace`ind' municipality year)
	gen temp_l1o = temp_tot - temp_`sk'
	gen temp_oth = temp_num - mainsamp
	gen temp_l1om = temp_l1o/temp_oth if `sk'!=.
	egen l1o`ind'_`sk' = total( temp_l1om * (year==2007) ), by(nipc) 
	drop temp_*
	}
}

	
*Winsorize spillover shocks
unab l1ovars: l1o*
local ny : word count `l1ovars'

forvalues y = 1/`ny' {
	
	local var : word `y' of `l1ovars'
	
	*save original
	cap gen raw`var' = `var'
	

	replace `var' = . if `var'==0
	
	
	summ `var'  if mainsamp==1 &year==2007, d
	local t1 = r(p5)
	local t2 = r(p95)
	local t75= r(p75)
	local t25 = r(p25)
	
	
	*winsorize
	replace `var' = `t1' if `var' < `t1' & `var'!=.
	replace `var' = `t2' if `var' > `t2' & `var'!=.
}




*****************************************
** 4. Create Pre Period Controls, and Baseline Levels for Changes and Scaling
*****************************************

*deflate balance sheet variables (many are alternative versions of QP/Export data vars)
foreach var in  exports payroll turnover sales_goods inventories labor_cost wages_paid ///
				contemp_ot totbasewage_incumbs contemp_basewage contemp_nomcomp ///
				total_exports_goods total_exports domestic_sales {
				replace `var' = `var'*deflator
}				


*Average pre-period employment
egen employees0507 = total( employees * inrange(year,2005,2007)*(1/3)), by(nipc) 
egen emp0507 = total( emp * inrange(year,2005,2007)*(1/3)), by(nipc)
egen hours0507 = total( hours * inrange(year,2005,2007)*(1/3)), by(nipc)


*2007 Characteristics
egen nprod2007 = max((year==2007)*nprod), by(nipc)
egen employees2007 = total( employees * (year==2007)), by(nipc) 
egen emp2007 = total( emp * (year==2007)), by(nipc)
egen hours2007 = total( hours * (year==2007)), by(nipc)
egen payroll2007 = total( payroll * (year==2007) ), by(nipc)
egen turnover2007 = total( turnover * (year==2007) ), by(nipc)
egen exports2007 = total( exports * (year==2007) ), by(nipc)


rename sh_fixed ftcshr

*Main pre-period (05-07) averages
foreach var in employees turnover exports hire ftcshr ndest emp HHI total_exports_goods total_exports sales_goods {
	cap egen `var'_pre = total( `var' * inrange(year,2005,2007) ), by(nipc)
	replace `var'_pre = `var'_pre / 3
	cap drop l`var'
	gen l`var' = log(`var')
	cap egen l`var'_pre = total( l`var' * inrange(year,2005,2007) ), by(nipc)
	replace l`var'_pre = l`var'_pre / 3
}

/*Export intensity for interactions, controls*/

*Main def
gen expint_pre = exports_pre/(turnover_pre*1000)
replace expint_pre = 0 if expint_pre==.
replace expint_pre = 1 if expint_pre > 1

*Alternative definitions using balance sheet exports
gen expint_new_pre =total_exports_goods_pre/turnover_pre
replace expint_new_pre = 1 if expint_new_pre > 1

gen expint_new2_pre =total_exports_goods_pre/sales_goods_pre
replace expint_new2_pre = 1 if expint_new2_pre > 1

	

*****************************************
**5. Define Firm Level Analysis Variables
*****************************************


**************
*A. Value Added
**************

*Two methods of calculation
*Traditional: Value of shipments - material cots ( - costs of purchased services + change in inventories)

cap drop va* lva* 
cap drop inventories_change

tsset nipcbdp year
gen inventories_change =  inventories - L.inventories


gen va1 = sales +  inventories_change - material_cost - services_cost 
gen va2 = sales - material_cost - services_cost
gen va3 = sales - material_cost 

*Preferred alternative: EBITDA (Profits + Interest + Taxes + Depreciation) + Wages ( + costs of purchased services). Follows Card, Cardoso, Heining, Kline
gen va_alt1 = ebitda +  labor_cost
gen va_alt2 = ebitda +  wages_paid 

label var va1 		"VA: Sales + DInv - MatServ"
label var va2 		"VA: Sales - MatServ"
label var va3 		"VA: Sales - Mat"
label var va_alt1 	"VA: Ebitda + lab cost"
label var va_alt2 	"VA: Ebitda + Wage"

*Trim negatives
foreach va in va1 va2 va3 va_alt1 va_alt2{
	replace `va' = . if `va' <= 1
	gen `va'_w = `va'/employees
	gen l`va'_w  = ln(`va'_w)
	gen l`va'  = ln(`va')

}

egen va_alt12007 = total( va_alt1 * (year==2007) ), by(nipc)

*va_alt 1 is main version for analysis

****************************
*B. Make DHS arc elasticities
****************************

foreach var in employees payroll turnover exports emp va_alt1{
	gen arc_`var' = (`var' - `var'2007) / (.5*(`var' + `var'2007))
	gen `var'_sc=(`var' / `var'2007)
	
	forval y = 2005/2013{
	centile `var'_sc if  year== `y' & mainsamp==1, c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  `var'_sc = `p2' if  `var'_sc < `p2' & ( year== `y')
	replace  `var'_sc = `p98' if  `var'_sc > `p98' &  `var'_sc != . & ( year== `y')
	
	centile arc_`var' if  year== `y' & mainsamp==1, c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  arc_`var' = `p2' if  arc_`var' < `p2' & ( year== `y')
	replace  arc_`var' = `p98' if  arc_`var' > `p98' &  arc_`var' != . & ( year== `y')
	}
}

*************************
*C. Logs, Zeros,  etc*
*************************

gen avgwage = 	payroll/emp

gen log_avgwage = log(payroll/emp)

*average new hire wage

gen logemp=log(emp)
gen logpayroll = log(payroll)
gen logincumbs = log(incumbs)
gen logtotovert = log(contemp_ot)
gen logwages_paid = log(wages_paid)
gen loglabor_cost= log(labor_cost)
gen logavgwagebill=log(wages_paid/employees)
gen logavglabcost=log(labor_cost/employees)
gen logincumbcost = log(earn_stayer)
gen logcontempcomp = log( contemp_comp)
gen logdomsales = log(domestic_sales)

replace contemp_basewage = 0 if contemp_basewage ==.
replace totbasewage_incumbs = 0 if totbasewage_incumbs ==.

gen logtotincwages = log(totbasewage_incumbs)
replace contemp_basewage = 0 if contemp_basewage ==.


*Define new hire wage bill as total wage bill minus wage bill for incumbent workers
gen logtothirewages = log(contemp_basewage-totbasewage_incumbs)
gen logtotwages = log(contemp_basewage)


gen yl = turnover/employees
gen log_yl = ln(yl)





*Extensive Margin Indicators
replace emp = 0 if emp==.

gen exit3 = emp == 0
gen any_emp = logemp!=.
gen any_employees = logemployees!=.
gen any_turnover = logturnover!=.
gen any_exp = logexports!=.


*Main continuers flag: never exits
egen everexit = max(exit3), by(nipcbdp)




********************************************
*D. Construct Cumulative post 2005 hires and fires
******************************************

*Employment change in % of 2007 emp
cap drop emp_sc
gen emp_sc = emp/emp2007

*calculate cumulative hires/seps since 2007
*Initialize
gen hire_since07 = 0
replace hire_since07 = hire if year==2008
gen sep_since07 = 0
replace sep_since07 = sepnext if year==2008
gen prm_since07 = 0
replace prm_since07 = promote if year==2008
gen hf_since07 = 0
replace hf_since07 = hirefirst if year==2008

*Iterate
forval yr = 2009/2013{
	replace hire_since07 = hire + L.hire_since07 if year == `yr'
	replace sep_since07 = sepnext + L.sep_since07 if year == `yr'	
	replace prm_since07 = promote + L.prm_since07 if year == `yr'
	replace hf_since07 = hirefirst + L.hf_since07 if year == `yr'
}	

*Backfill to 2005
forval t = 1/2{
	local yr = 2007-`t'
	replace hire_since07 = F.hire_since07 - F.hire if year == `yr'
	replace sep_since07 =  F.sep_since07 - F.sepnext if year == `yr'		
	replace prm_since07 =  F.prm_since07 - F.promote if year == `yr'
	replace hf_since07 =  F.hf_since07 - F.hirefirst if year == `yr'
}	


*Common 2007 employment denominator
gen hire_sc = hire_since07 / emp2007
gen sep_sc = sep_since07 / emp2007

gen arc_hire = hire_since07 / (.5*(emp + emp2007))
gen arc_sep = sep_since07 / (.5*(emp + emp2007))

gen prm_sc = prm_since07 / emp2007
gen hf_sc = hf_since07 / emp2007


*Alternative metrics
gen hireout = hire>0 & hire!=.
gen hirert = hire/emp
gen seprt = sepnext/emp 


*separations of NEW hires = (total seps / 2007 emp  - seps of incumbs / 2007 emp)
gen  sep_new_sc = sep_sc -(1-same_firm)

*Employment from new hires (net of retention)

gen hire_rt_sc = hire_sc - sep_new_sc


gen sep_cont = (1-same_firm) * (emp>0)
gen sep_exit = (1-same_firm) * (emp==0)





*********************************************
*E. WINSORIZE OUTCOMES IN SAMPLE, BY YEAR
********************************************


*Merge in annual aveage wages of employees / new hires. Variables are already winsorized in sample in collapse_contemp.do

merge 1:1 nipcbdp year using "${path}/Aggregate Shock/Data/collapse_contemp.dta", keep(1 3) nogen


*drop old collapse variables not in use now
drop logaltnomhwage_perm logaltnomsalary_perm log2nomhwage_perm log2nomsalary_perm arc_hwage_perm arc_salary_perm arc_nomhwage_perm arc_nomsalary_perm ///
				logaltnomhwage_attached logaltnomsalary_attached log2nomhwage_attached log2nomsalary_attached arc_hwage_attached arc_salary_attached arc_nomhwage_attached arc_nomsalary_attached ///
				lognomsalary_wagelo lognomsalary_wagehi lognomhwage_wagelo lognomhwage_wagehi lognomhwage_perm  loghours_perm loghnorm_perm otratio_perm loghours_attached loghnorm_attached otratio_attached	

				

foreach var in log_yl lognomsalary lognomhwage logtotwages  logtothirewages logtotincwages logincumbs logtotovert ///
				logrealhwage logrealsalary logrealhwage_attached logrealsalary_attached {
				
		
	*forval s = 1/4{
	*forval a = 1/13{
	forval y = 2005/2013{
	
	centile `var' if  year== `y' & mainsamp==1, c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  `var' = `p2' if  `var' < `p2' & ( year== `y')
	replace  `var' = `p98' if  `var' > `p98' &  `var' != . & ( year== `y')
	
	}
	*}
	*}
	
}

*Employment/flow variables

foreach var in hire hf prm emp sep hire_rt sep_new { 
		
	*forval s = 1/4{
	*forval a = 1/13{
	forval y = 2005/2013{
	
	centile `var'_sc if  year== `y' & mainsamp==1, c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  `var'_sc = `p2' if  `var'_sc < `p2' & ( year== `y')
	replace  `var'_sc = `p98' if  `var'_sc > `p98' &  `var'_sc != . & ( year== `y')
	
	}
	*}
	*}
	
}


*Hours Variables

foreach var in hours hnormal hovertime inc_hours inc_hoursperm inc_hoursftc inc_hoursattached{
	gen `var'_sc =  `var'/emp2007
	gen `var'_hsc =  `var'/hours2007
	
	forval y = 2005/2013{
	
	centile `var'_sc if  year== `y' & mainsamp==1, c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  `var'_sc = `p2' if  `var'_sc < `p2' & ( year== `y')
	replace  `var'_sc = `p98' if  `var'_sc > `p98' &  `var'_sc != . & ( year== `y')
	
	centile `var'_hsc if  year== `y' & mainsamp==1, c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  `var'_hsc = `p2' if  `var'_hsc < `p2' & ( year== `y')
	replace  `var'_hsc = `p98' if  `var'_hsc > `p98' &  `var'_hsc != . & ( year== `y')
	}
}

*Make log 1 + vars and winsorize

foreach var in exports turnover employees emp payroll va1 va2 va_alt1 earnings ebitda{
	summ `var' if (mainsamp==1) & year==2007, d
	local m = r(p50)
	gen logalt`var'  = ln( `var' + `m')
	gen log2`var'  = ln( `var' + 1)
	
	forval y = 2005/2013{
	
	centile logalt`var' if  year== `y' & mainsamp==1, c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  logalt`var' = `p2' if  logalt`var' < `p2' & ( year== `y')
	replace  logalt`var' = `p98' if  logalt`var' > `p98' &  logalt`var' != . & ( year== `y')
	
	centile log2`var' if  year== `y' & mainsamp==1, c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  log2`var' = `p2' if  log2`var' < `p2' & ( year== `y')
	replace  log2`var' = `p98' if  log2`var' > `p98' & log2`var' != . & ( year== `y')
	}
	
	
	
	
}


*Per-worker vars

foreach s in exports turnover va2 va_alt1 payroll ebitda earnings{
	
	
	gen `s'_inc = `s'/emp
	egen `s'_inc2007 = total( `s'_inc * (year==2007) ), by(nipc)
	summ `s'_inc2007 if (sample3==1) & year==2007, d
	local m = r(p50)
	gen logalt`s'_inc  = ln( `s'_inc + `m')
	gen log2`s'_inc  = ln( `s'_inc + 1)
	
	*arc elasticities
	gen l`s'_inc = log(`s'_inc)
	gen arc_`s'_inc  = (`s'_inc  - `s'_inc 2007) / (.5*(`s'_inc  + `s'_inc2007))
	
	*Currently dont use these
	centile arc_`s'_inc if mainsamp==1, c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  arc_`s'_inc  = `p2' if  arc_`s'_inc  < `p2' 
	replace  arc_`s'_inc  = `p98' if  arc_`s'_inc  > `p98' &  arc_`s'_inc  != . 
	
	
	centile l`s'_inc , c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  l`s'_inc = `p2' if  l`s'_inc < `p2' 
	replace  l`s'_inc = `p98' if  l`s'_inc > `p98' &  l`s'_inc != . 
	
	
	gen `s'_l = `s'/employees
	egen `s'_l2007 = total( `s'_l * (year==2007) ), by(nipc)
	summ `s'_l2007 if (sample3==1) & year==2007, d
	local m = r(p50)
	gen logalt`s'_l  = ln( `s'_l + `m')
	gen log2`s'_l  = ln( `s'_l + 1)
*arc elasticities
	gen l`s'_l = log(`s'_l)
	gen arc_`s'_l  = (`s'_l  - `s'_l 2007) / (.5*(`s'_l  + `s'_l2007))
	
	
	centile arc_`s'_l  if mainsamp==1, c(2 98)
	local p2 = r(c_1)
	local p98 = r(c_2)
	
	replace  arc_`s'_l  = `p2' if  arc_`s'_l  < `p2' 
	replace  arc_`s'_l  = `p98' if  arc_`s'_l  > `p98' &  arc_`s'_l  != . 
	
	forval y = 2005/2013{
		centile `s'_l if  year== `y' & mainsamp==1, c(2 98)
		local p2 = r(c_1)
		local p98 = r(c_2)
		
		replace  `s'_l  = `p2' if  `s'_l  < `p2' & ( year== `y')
		replace  `s'_l  = `p98' if  `s'_l  > `p98' &  `s'_l  != . & ( year== `y')
	
	
		centile l`s'_l if  year== `y' & mainsamp==1, c(2 98)
		local p2 = r(c_1)
		local p98 = r(c_2)
		
		replace  l`s'_l = `p2' if  l`s'_l < `p2'  & ( year== `y')
		replace  l`s'_l = `p98' if  l`s'_l > `p98' &  l`s'_l != .  & ( year== `y')
		
	}
}



*Extra control

foreach var in lognomhwage lva_alt1_l {
	cap egen `var'_pre = total( `var' * inrange(year,2005,2007) ), by(nipc)
	replace `var'_pre = `var'_pre / 3

}


*********************************
**F. Add in heterogeneity vars
*********************************


egen alwaysexp = min(logexports!=.), by(nipcbdp)
egen alwaysemp = min(logemp!=.), by(nipcbdp)



**Firm/industry heterogeneity variables
rename nace5 nace5d
*main turnover variables
merge m:1 nipcbdp using "$Data/indturnoverv3.dta", keep(1 3) nogen

*industry HHI
merge m:1 nace5d using "$Data/indturnoverv4.dta", keep(1 3) nogen

*AKM Estimated on Permanent Contract Movers
merge m:1 nipcbdp using "$Data/akm0307firmperm1", nogen keep(1 3)
rename akmfirm akmperm


rename nace5d nace5

*Main Heterogeneity Variables
local newhet ind5d_ooswmn_perm_medtenure ind5d_grow5yr HHIemp ind5d_ooswmn_quit_perm akmperm

*Note: Residual turnover and wage cushions are made in separate codes and merged in

*Winsorize, make in-sample median split
foreach var in `newhet'{
	summ `var'  if sample3==1 & mainsamp==1 & year==2007, d
	local t1 = r(p5)
	local t2 = r(p95)
	local med = r(p50)
	local hi = r(p75)
	local lo = r(p15)

	gen hi_`var'=0 if `var' < `med'
    replace hi_`var'=1 if `var' >`med' & `var'!=.
	
	gen vhi_`var'=0 if `var' < `lo'
    replace vhi_`var'=1 if `var' >`hi' & `var'!=.
	
	
	*winsorize
	replace `var' = `t1' if `var'<`t1' & `var'!=.
	replace `var' = `t2' if `var'>`t2' & `var'!=.
}


local hetvar ind5d_ooswmn_perm_medtenure 


*********************************
**F. Odds and Ends and Save 
*********************************


***gen alternative weights
gen wt1 = 1
gen wt2 = sqrt_avgemploy
gen wt3 = emp2007


****Add on industry growth vars
replace  cae3_2d = cae3_2d_2007 
merge m:1 cae3_2d using "$Data/ies_industry.dta", keep(1 3) nogen


*add firm main products	from shock construction code. Here, use original version, not repl. copy
merge m:1 nipcbdp using "$Data/mainprodhs6.dta", keep(1 3) nogen
merge m:1 nipcbdp using "$Data/mainprodhs4.dta", keep(1 3) nogen
merge m:1 nipcbdp using "$Data/mainprodhs2.dta", keep(1 3) nogen




*****Save core firm dataset

tsset nipc year

save "${path}/Aggregate Shock/replication/data_out/analysis_samp.dta", replace



********Auxiliary Datasets 
use "$Data/analysis_samp", clear
unab l1ovars: l1o4_shock* l1o4_idshock* l1o4_comshock* 
unab maints:  shock* impshock* comshock* idshock*  trimshock* trimcomshock* trimidshock*

local tlist   `l1ovars' `maints' 
 

*Create dataset of treatments for baseline firms of employees
preserve

rename everexit everexit_frommainset
keep if year==2007
unab hihet: hi_* 
keep nipcbdp  `tlist' `newhet' 
save "${path}/Aggregate Shock/replication/data_out/treatments_for_emp.dta", replace
restore

preserve

keep if year==2007
keep nipcbdp lturnover_pre mainhs2 mainhs4 lexports_pre exports_pre lemployees_pre employees_pre turnover_pre lognomhwage_pre lva_alt1_l_pre ltotal_assets_pre ftcshr_pre hirertpre lndest_pre  lHHI_pre expshrAGO expshrESP expshrUSA expshrNLD expshrMOZ expshrGBR expshrFRA expshrDEU expshrCPV expshrBRA expshrBEL
save "${path}/Aggregate Shock/replication/data_out/extracontrols_for_emp.dta", replace
restore

*Create dataset of firststage vars
preserve
keep nipcbdp  year  logturnover  lva_alt1    log2turnover  log2va_alt1  turnover_sc va_alt1_sc arc_turnover arc_va_alt1
save "${path}/Aggregate Shock/replication/data_out/fs_for_emp.dta", replace
restore


*Create dataset of exits for baseline firms of employees
preserve
keep nipcbdp year exit* 
save "${path}/Aggregate Shock/replication/data_out/exits_for_emp.dta", replace
restore


*baseline nipcs to extract from QP
keep nipcbdp sample3 
duplicates drop
save "${path}/Aggregate Shock/replication/data_out/sample3codes.dta", replace


cap log close


