************************************
* Prepare Worker-Level Data   	   *
* Andy Garin (agarin@illinois.edu) *
************************************

*
*Reads in panel of incumbent workers (based on 2007 employment) at sample firms 
*
*Applies sample restrictions, merges in firm-level variables, cleans analysis variables.
*
*1_prep_firm_data must be run first.
*
*See readme for variable descriptions
*


cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"



*****************************
**1. Preliminaries
*****************************

*Set incumbency year as 2007
global baseyear = 2007

clear all
set more off
set matsize 11000


**Get firm treatments from replication data

use "${path}/Aggregate Shock/replication/data_out/analysis_samp.dta", clear

keep if year==2007

rename everexit everexit_frommainset

keep nipcbdp shock0610hs6 idshock0610* comshock0610* l1o4_shock0610hs6 l1o4_idshock0610* l1o4_comshock0610* trimshock0610hs6 ///
	trimcomshock0610* trimidshock0610*  expint_pre expint_new_pre expint_new2_pre expshrAGO expshrESP HHIemp ///
	hi_* nace5 cae3_2d_2007 mainsamp HHIemp ind5d_ooswmn_perm_medtenure ind5d_ooswmn_quit_perm mainhs* 
	
tempfile t4e

save `t4e'	

clear


***********************************
**2. Read in main incumbent info 
************************************

use year nipcbdp nss samp2007 sample3 rem_base lths age gender_pre t_real_wage wagegroup t_real_h_wage hsdeg ///
			prof1d_pre qualif_pre tenure_pre age_pre coldeg ctype_pre loghours ///
			loghnorm nipcbdp  nomhwage realsalary realhwage realjob qpemp same_firm ///
			prom_since07 hours hnormal log2nomsalary    logrealhwage logrealsalary lognomhwage  ///
			lognomsalary lognomtsalary log2nomsalary log2nomhwage hnormal logrealcomp ///
			lognomhwage_stayer lognomsalary_stayer logrealcomp_stayer earnfrac_stayer ///
			using "${path}Aggregate Shock/Data/draft1_sample_workers_clean$baseyear", replace

cap drop _merge

***********************************
**3. Winsorize outcomes in sample
************************************

drop loghours loghnorm realhwage logrealhwage logrealsalary 

foreach var in hours hnormal realsalary{ 

	forval y = 2002/2013{
	
		centile `var' if  year== `y' & `var'>0 & `var'!=. , c(5 95) 
		local p5 = r(c_1)
		local p95 = r(c_2)
		
		replace  `var' = `p5' if  `var' < `p5' & ( year== `y') & `var'>0 & `var'!=.
		replace  `var' = `p95' if  `var' > `p95'  & ( year== `y') & `var'>0 & `var'!=.
		
	}

gen log`var' = log(`var')
	
}

*generate hourly wages, winsorize again

gen realhwage = realsalary/hnormal

foreach var in realhwage{ 

	forval y = 2002/2013{
	
	centile `var' if  year== `y' & `var'>0 & `var'!=. , c(5 95)
		local p5 = r(c_1)
		local p95 = r(c_2)
		
		replace  `var' = `p5' if  `var' < `p5' & ( year== `y') & `var'>0 & `var'!=.
		replace  `var' = `p95' if  `var' > `p95'  & ( year== `y') & `var'>0 & `var'!=.
		
	}

gen log`var' = log(`var')
	
}

***********************************
**4. Merge in firm-level vars
***********************************

*Treatments, controls, heterogeneity

merge m:1 nipcbdp using `t4e', keep(3) keepusing( ///
	nipcbdp shock0610hs6 idshock0610* comshock0610* l1o4_shock0610hs6 l1o4_idshock0610* l1o4_comshock0610* trimshock0610hs6 ///
	trimcomshock0610* trimidshock0610*  expint_pre expint_new_pre expint_new2_pre expshrAGO expshrESP HHIemp ///
	hi_* nace5 cae3_2d_2007 mainsamp HHIemp ind5d_ooswmn_perm_medtenure ind5d_ooswmn_quit_perm mainhs* ) nogen
	

*First-stage outcomes for pass-through, from replicated build
merge m:1 nipcbdp year using "${path}/Aggregate Shock/replication/data_out/fs_for_emp.dta", keep(1 3) nogen

gen log2realhwage = log(1+realhwage)
gen log2realsalary = log(1+realsalary)

*get exits, from replicated build: note, pre years will not match
merge m:1 nipcbdp year using "${path}/Aggregate Shock/replication/data_out/exits_for_emp.dta"
drop if _merge==2
drop _merge

egen everexit = max(exit3), by(nipcbdp)


***********************************
**5. Core Sample Selection
***********************************

*Flag more-attached incumbents
egen yearspre = total(same_firm * inrange(year, 2005 , 2007)), by(nss)
gen attached = (yearspre== 3)


***Restrict to base year incumbents
keep if samp$baseyear == 1


***Restrict to full-time incumbents
egen hours2007 = total(hnormal*(year==2007)), by(nss)
keep if inrange( hours2007, 120, 200)



***********************************
**6. Main variable definitions
***********************************

*arc-percent changes 
egen baserealsalary = total(realsalary* (year==$baseyear)), by(nss)
gen arc_salary = (realsalary - baserealsalary) / (.5*(realsalary + baserealsalary))
egen baserealhwage = total(t_real_h_wage* (year==$baseyear)), by(nss)
gen arc_hwage = (t_real_h_wage - baserealhwage) / (.5*(t_real_h_wage + baserealhwage))



*make versions of variables that are missing if not at baseline firm in 
foreach var in  logrealhwage logrealsalary{
	 gen `var'_stayer = `var' if same_firm==1
}


*Inverse Hyperbolic Sine var
gen asinhsalary = asinh(12*realsalary/1000)
gen asinhhwage= asinh(realhwage)



***********************************
**6. Worker types for heterogeneity
***********************************

cap drop ftc
cap drop perm
cap drop female 
cap drop young
cap drop old
cap drop primeage
cap drop male


gen newbie = attached==0

*FTC versus perm
gen ftc = ctype_pre == 2
gen perm = ctype_pre == 1 


gen col = coldeg==1 

gen wagehi =  wagegroup ==2

gen wagelo =  wagegroup ==1

gen young = age_pre <30  
gen old = age_pre > 50 
gen lten= inrange(tenure_pre, 120,600) 


*Main heterogeneity groups, focus on permanent-contract workers

gen manag = (prof1d_pre==1) & perm==1 
gen skld = (prof1d_pre==2|prof1d_pre==7) & perm==1 
gen unsk = !(prof1d_pre==1|prof1d_pre==2|prof1d_pre==7) & perm==1 
gen bcsk = (prof1d_pre==7) & perm==1 
gen wc = (prof1d_pre==2|prof1d_pre==3|prof1d_pre==4|prof1d_pre==5) & perm==1 
gen bc = (prof1d_pre==7|prof1d_pre==8|prof1d_pre==9) & perm==1 
gen bcun = (prof1d_pre==8|prof1d_pre==9) & perm==1 


gen female = gender_pre == 2 & perm==1 
gen male = gender_pre == 1 & perm==1 
gen nohs = hsdeg == 0 & perm==1 




save "${path}/Aggregate Shock/replication/data_out/worker_panel.dta", replace
cap log close

